@@ -47,6 +47,8 @@
  * 09 Nov 08, arkadiusz.firus@gmail.com: support for -t <tag_file>
  		and read stdin if no input file provided
  * 13 Dec 08, daved@physiol.usyd.edu.au: search path code
+ * 17 Jan 10, daved@physiol.usyd.edu.au: change search path to directory
+ *		containing output conf and font charmap files
  *--------------------------------------------------------------------*/
 
 #ifdef HAVE_CONFIG_H
@@ -126,9 +128,10 @@ get_config(char *path, OutputPersonality *op, int mode)
 			{
 				char *p;
 				p = path_dir_p->dir_name;
-				if(*(p+strlen(p)) != '/')
+				if(*(p+strlen(p)-1) != '/')
 					p = concatenate(p, "/");
-				user_path=concatenate(p, path);
+				p=concatenate(p, path);
+				user_path=concatenate(p, ".conf");
 				if(access(user_path, F_OK|R_OK))
 					continue;
 				op = user_init(op, user_path);
@@ -137,12 +140,13 @@ get_config(char *path, OutputPersonality *op, int mode)
 			}
 			if(!u_success)
 			{
-				fprintf(stderr, "failed to find %s in search path dirs\n", path);
+				fprintf(stderr, "failed to find %s.conf in search path dirs\n", path);
 				exit(1);
 			}
 			break;
-			case 1:
-			absolute_path = concatenate(CONFIG_DIR, path);
+		case 1:
+			path = concatenate(CONFIG_DIR, path);
+			absolute_path = concatenate(path, ".conf");
 			op = user_init(op, absolute_path);
 			my_free(absolute_path);
 			break;
@@ -223,7 +227,18 @@ main (int argc, char **argv)
 		else if (!strcmp("--nopict", argv[i])) nopict_mode = TRUE;
 		else if (!strcmp("-n", argv[i])) nopict_mode = TRUE;
 		else if (!strncmp("--", argv[i], 2))
-			op = get_config(&argv[i][2], op, 1);
+#if 0 /* daved 0.21.1 */
+			op = get_config(&argv[i][2], op, 1)
+#else
+		{
+			if(!path_checked && check_dirs() == 0)
+			{
+				fprintf(stderr,"no config dirs for %s\n", argv[i]);
+				exit(1);
+			}
+			op = get_config(&argv[i][2], op, 0);
+		}
+#endif
 		else {
 			if (*argv[i] == '-') usage();
 
