@@ -149,4 +149,19 @@ my_strdup (char *src) {
 	strcpy (ptr, src);
 	return ptr;
 }
+/* added by daved */
+#include <sys/types.h>
+#undef malloc
+     
+void *malloc ();
+        
+/* Allocate an N-byte block of memory from the heap.
+If N is zero, allocate a 1-byte block.  */
 
+void *
+rpl_malloc (size_t n)
+{    
+  if (n == 0)
+	   n = 1;
+return malloc (n);
+}    
