@@ -22,6 +22,8 @@
 #include <stdlib.h>
 #endif
 
+extern int verbose_mode;
+
 my_iconv_t
 my_iconv_open(const char *tocode, const char *fromcode)
 {
@@ -55,7 +57,7 @@ my_iconv_open(const char *tocode, const char *fromcode)
 #endif
 #if 1 /* daved 0.21.1 */
 		}
-		if((f = fopen(path, "r")) == NULL)
+		if((f = fopen(path, "r")) == NULL && verbose_mode)
 			fprintf(stderr, "failed to open charmap file %s\n", path);
 #else
 		f = fopen(path, "r");
