@@ -37,6 +37,8 @@
  * 17 Dec 07, daved@physiol.usyd.edu.au: added support for --noremap from
  *		David Santinoli
  * 09 Nov 08, arkadiusz.firus@gmail.com: use iconv
+ * 21 Aug 10, daved@physiol.usyd.edu.au: add code to deal with character
+ 	doublets (see convert.c)
  *--------------------------------------------------------------------*/
 
 
@@ -153,7 +155,11 @@ op_translate_char (OutputPersonality *op, my_iconv_t cd, int ch)
 
 			if (my_iconv(cd, &inbuf, &inbytes, &outbuf, &outbytes) == -1)
 			{
+#if 1 /* daved */
 				fprintf(stderr, "unrtf: Error in executing iconv1\n");
+#else
+				fprintf(stderr, "unrtf: Error in executing iconv1\n");
+#endif
 				return NULL;
 			}
 			
@@ -211,7 +217,255 @@ op_translate_char (OutputPersonality *op, my_iconv_t cd, int ch)
 	return result;
 }
 
+#if 0 /* daved - 0.21.2 */
+/*========================================================================
+ * Name:	op_translate_str
+ * Purpose:	Performs a translation of a doublet the context of
+ *		a given output personality.
+ * Args:	OutputPersonality, character set#, character.
+ * Returns:	String.
+ *=======================================================================*/
 
+char *
+op_translate_str (OutputPersonality *op, my_iconv_t cd, int * doublet)
+{
+	short start;
+	char *result=NULL;
+	static char output_buffer[3]={ 0, 0, 0 };
+	unsigned char *inbuf;
+	char *outbuf;
+	int	ch;
+
+	fprintf(stderr, "doublet = %o %o\n", *doublet, *(doublet+1));
+#if 0
+	size_t inbytes = (ch / 256) + 1, outbytes = inbytes * 4, i;
+#else
+	size_t inbytes = 3, outbytes = inbytes * 4, i;
+#endif
+
+	CHECK_PARAM_NOT_NULL(op);
+
+#if 0
+	if (no_remap_mode == TRUE && ch < 256)
+	{
+		output_buffer[0]=ch;
+		result=output_buffer;
+	}
+	else
+	if (result == NULL)
+	{
+#endif
+		inbuf = (char *) my_malloc(inbytes + 1);
+		*inbuf = *doublet;
+		*(inbuf+1) = (unsigned char *) *(doublet+1);
+		*(inbuf+2) = 0;
+		fprintf(stderr, "inbuf = %o %o\n", *inbuf, *(inbuf+1));
+		outbuf = my_malloc(outbytes + 1);
+
+#if 0
+
+		for (i = inbytes - 1; ch > 255; i--)
+		{
+			inbuf[i] = ch % 256;
+			ch /= 256;
+		}
+
+		inbuf[0] = ch;
+		inbuf[inbytes] = '\0';
+#endif
+		i = outbytes;
+		if (!my_iconv_is_valid(cd))
+		{
+			cd = my_iconv_open("UTF-8", "cp1252");
+
+			if (my_iconv(cd, &inbuf, &inbytes, &outbuf, &outbytes) == -1)
+			{
+				fprintf(stderr, "unrtf: Error in executing iconv1\n");
+				return NULL;
+			}
+			
+			my_iconv_close(cd);			
+		}
+		else
+		{
+
+			if (my_iconv(cd, &inbuf, &inbytes, &outbuf, &outbytes) == -1)
+			{
+#if 1 /* daved */
+				fprintf(stderr, "unrtf: Error in executing iconv - inbytes=%d inbuf[0]=%o inbuf[1]=%o\n", inbytes, inbuf[0], inbuf[1]);
+#else
+				fprintf(stderr, "unrtf: Error in executing iconv\n");
+#endif
+				return NULL;
+			}
+		}
+		*outbuf = '\0';
+		outbuf -= i - outbytes;
+/* Conversion from string to utf8 code number */
+		inbytes = 0;
+
+		for (i = 0; outbuf[i] != '\0'; i++)
+			inbytes++;
+
+		ch = 0;
+
+		for (i = 0; i < inbytes; i++)
+		{
+			if (i == 0)
+				switch (inbytes)
+				{
+					case 1:
+						ch =  outbuf[0];
+						break;
+					case 2:
+						ch = (unsigned char) outbuf[0] - 192;
+						break;
+					case 3:
+						ch = (unsigned char) outbuf[0] - 224;
+						break;
+					case 4:
+						ch = (unsigned char) outbuf[0] - 240;
+						break;
+				}
+			else
+				ch = (ch * 64) + ((unsigned char) outbuf[i] - 128);
+		}
+/* End of conversion*/
+
+		result = get_alias(op, ch);
+
+		if (result == NULL)
+			if (ch > 127 && op->unisymbol_print)
+				result = assemble_string(op->unisymbol_print, ch);
+			else
+				result = outbuf;
+#if 0 /* daved 0.21.2 */
+	}
+#endif
+
+	return result;
+}
+#endif
+
+#if 1 /* daved - 0.21.2 */
+/*========================================================================
+ * Name:	op_translate_doublet
+ * Purpose:	Performs a translation of a doublet the context of
+ *		a given output personality.
+ * Args:	OutputPersonality, character set#, character byte 1 and 2
+ * Returns:	String.
+ *=======================================================================*/
+
+char *
+op_translate_doublet (OutputPersonality *op, my_iconv_t cd, int ch1, int ch2)
+{
+	short start;
+	char *result=NULL;
+	static char output_buffer[3]={ 0, 0, 0 };
+	unsigned char *inbuf;
+	char *outbuf;
+	int	ch;
+
+#if 0
+	size_t inbytes = (ch / 256) + 1, outbytes = inbytes * 4, i;
+#else
+	size_t inbytes = 3, outbytes = inbytes * 4, i;
+#if 0
+	fprintf(stderr, "doublet = %o %o\n", ch1, ch2);
+#endif
+#endif
+
+	CHECK_PARAM_NOT_NULL(op);
+
+	if (no_remap_mode == TRUE && ch < 256)
+	{
+		output_buffer[0]=ch1;
+		output_buffer[1]=ch2;
+		result=output_buffer;
+	}
+	else
+	if (result == NULL)
+	{
+		inbuf = (char *) my_malloc(inbytes + 1);
+		*inbuf = ch1;
+		*(inbuf+1) = ch2;
+		*(inbuf+2) = 0;
+#if 0
+		fprintf(stderr, "inbuf = %o %o\n", *inbuf, *(inbuf+1));
+#endif
+		outbuf = my_malloc(outbytes + 1);
+
+		i = outbytes;
+		if (!my_iconv_is_valid(cd))
+		{
+			cd = my_iconv_open("UTF-8", "cp1252");
+
+			if (my_iconv(cd, (char **)&inbuf, (size_t *)&inbytes, (char **)&outbuf, &outbytes) == -1)
+			{
+				fprintf(stderr, "unrtf: Error in executing iconv1\n");
+				return NULL;
+			}
+			
+			my_iconv_close(cd);			
+		}
+		else
+		{
+
+			if (my_iconv(cd, (char **)&inbuf, (size_t *)&inbytes, (char **)&outbuf, &outbytes) == -1)
+			{
+#if 1 /* daved */
+				fprintf(stderr, "unrtf: Error in executing iconv - inbytes=%d inbuf[0]=%o inbuf[1]=%o\n", inbytes, inbuf[0], inbuf[1]);
+#else
+				fprintf(stderr, "unrtf: Error in executing iconv\n");
+#endif
+				return NULL;
+			}
+		}
+		*outbuf = '\0';
+		outbuf -= i - outbytes;
+/* Conversion from string to utf8 code number */
+		inbytes = 0;
+
+		for (i = 0; outbuf[i] != '\0'; i++)
+			inbytes++;
+
+		ch = 0;
+
+		for (i = 0; i < inbytes; i++)
+		{
+			if (i == 0)
+				switch (inbytes)
+				{
+					case 1:
+						ch =  outbuf[0];
+						break;
+					case 2:
+						ch = (unsigned char) outbuf[0] - 192;
+						break;
+					case 3:
+						ch = (unsigned char) outbuf[0] - 224;
+						break;
+					case 4:
+						ch = (unsigned char) outbuf[0] - 240;
+						break;
+				}
+			else
+				ch = (ch * 64) + ((unsigned char) outbuf[i] - 128);
+		}
+/* End of conversion*/
+
+		result = get_alias(op, ch);
+
+		if (result == NULL)
+			if (ch > 127 && op->unisymbol_print)
+				result = assemble_string(op->unisymbol_print, ch);
+			else
+				result = outbuf;
+	}
+
+	return result;
+}
+#endif
 /*========================================================================
  * Name:	op_begin_std_fontsize 
  * Purpose:	Prints whatever is necessary to perform a change in the
