@@ -254,6 +254,10 @@ OutputPersonality;
 extern OutputPersonality* op_create(void);
 extern void op_free (OutputPersonality*);
 extern char* op_translate_char (OutputPersonality *op, my_iconv_t cd, int ch);
+#if 1 /* daved - 0.21.2 */
+extern char* op_translate_str (OutputPersonality *op, my_iconv_t cd, int * doublet);
+extern char* op_translate_doublet (OutputPersonality *op, my_iconv_t cd, int ch1, int ch2);
+#endif
 
 extern void op_begin_std_fontsize (OutputPersonality*, int);
 extern void op_end_std_fontsize (OutputPersonality*, int);
