@@ -7,6 +7,8 @@
  * Changes:
  * 04 Jan 10, daved@physiol.usyd.edu.au: null terminate strings in
  *		unicode_to_string
+ * 21 Aug 10, daved@physiol.usyd.edu.au: test feof() rather than EOF for
+ 	AIX support
  *--------------------------------------------------------------------*/
 #include <stdio.h>
 
@@ -124,7 +126,11 @@ get_unicode_char(FILE *file)
 
 	c = fgetc(file);
 
+#if 1 /* daved 0.21.2 */
+	while (c != '>' && c != '\n' && !feof(file))
+#else
 	while (c != '>' && c != '\n' && c != EOF)
+#endif
 	{
 		unicode_number[len] = c;
 		c = fgetc(file);
